# -*- coding: utf-8 -*-
import os
import glob
import numpy as np
import imageio
from tqdm import tqdm
import time
from osgeo import gdal
from osgeo import osr
from osgeo import ogr
from osgeo.gdalconst import GA_Update


class GeoTiff:
    @staticmethod
    def to_img(img_format, gtif_path, save_path):
        gtifs = []
        if os.path.isdir(gtif_path):
            gtifs = glob.glob(gtif_path + r'\*.tif')
        elif os.path.isfile(gtif_path):
            if '.tif' in gtif_path or '.TIF' in gtif_path:
                gtifs.append(gtif_path)
        else:
            print('input path error.')
            exit(0)

        print('Geotiff convert to {0}:'.format(str.upper(img_format)))
        print(gtif_path)

        pbar = tqdm(total=len(gtifs))
        for gtif in gtifs:
            time.sleep(0.05)
            pbar.update(1)

            gtif_name = os.path.split(gtif)[-1]
            file_name = os.path.splitext(gtif_name)[0]
            src_ds = gdal.Open(gtif)
            if src_ds is None:
                # print('unable to open raster file:', gtif_name, '.')
                continue

            ncol = src_ds.RasterXSize
            nrow = src_ds.RasterYSize
            nband = src_ds.RasterCount
            data_uint8 = np.zeros((nrow, ncol, nband), dtype=np.uint8)
            for i in range(nband):
                srcband = src_ds.GetRasterBand(i + 1)
                data_origin = srcband.ReadAsArray(0, 0, ncol, nrow)
                if data_origin.dtype == np.uint8:
                    data_uint8[:, :, i] = data_origin
                else:
                    data_float = data_origin.astype(np.float)
                    data_unique = np.unique(data_float)
                    data_unique = data_unique.argsort()
                    # 取第二的最大最小值，防止黑边白边干扰
                    data_max = data_unique[-2]
                    data_min = data_unique[1]
                    data_float = (data_float - data_min) / (data_max - data_min) * 255
                    data_uint8 = data_float.astype(np.uint8)
            imageio.imwrite(os.path.join(save_path, file_name + '.' + img_format), data_uint8)
        pbar.close()

    @staticmethod
    def clip_by_size(clip_size, gtif_path, save_path):
        gtifs = []
        if os.path.isdir(gtif_path):
            gtifs = glob.glob(gtif_path + r'\*.tif')
        elif os.path.isfile(gtif_path):
            if '.tif' in gtif_path or '.TIF' in gtif_path:
                gtifs.append(gtif_path)
        else:
            print('input path error.')
            exit(0)

        print('Clip Geotiff with the size of ({0} * {1}) :'.format(clip_size[0], clip_size[1]))
        print(gtif_path)

        # Stop GDAL printing both warnings and errors to STDERR
        gdal.PushErrorHandler('CPLQuietErrorHandler')
        # Make GDAL raise python exceptions for errors (warnings won't raise an exception)
        gdal.UseExceptions()

        pbar = tqdm(total=len(gtifs))
        for gtif in gtifs:
            time.sleep(0.05)
            pbar.update(1)
            gtif_name = os.path.split(gtif)[-1]
            file_name = os.path.splitext(gtif_name)[0]
            src_ds = gdal.Open(gtif)
            if src_ds is None:
                # print('unable to open raster file:', gtif_name, '.')
                continue

            ncol = src_ds.RasterXSize
            nrow = src_ds.RasterYSize
            nband = src_ds.RasterCount

            src_data = []
            src_color = []
            for i in range(nband):
                srcband = src_ds.GetRasterBand(i + 1)
                src_data.append(srcband.ReadAsArray(0, 0, ncol, nrow))
                src_color.append(srcband.GetColorInterpretation())

            projection = src_ds.GetProjection()
            geotransform = src_ds.GetGeoTransform()

            dsize = clip_size
            dheight = int(nrow / dsize[0])
            dwidth = int(nrow / dsize[1])
            for i in range(dheight):
                for j in range(dwidth):
                    driver = gdal.GetDriverByName('GTiff')
                    out_ds = driver.Create(os.path.join(save_path, '{0}_{1}_{2}.tif'.format(file_name, str(i), str(j))), dsize[1], dsize[0], nband, gdal.GDT_Byte)

                    lux = geotransform[0] + j * dsize[1] * geotransform[1] + i * dsize[0] * geotransform[2]
                    luy = geotransform[3] + j * dsize[1] * geotransform[4] + i * dsize[0] * geotransform[5]
                    out_geom = (lux, geotransform[1], geotransform[2], luy, geotransform[4], geotransform[5])
                    out_ds.SetGeoTransform(out_geom)
                    out_ds.SetProjection(projection)

                    for k in range(nband):
                        out_data = src_data[k][(i * dsize[0]):((i + 1) * dsize[0]), (j * dsize[1]):((j + 1) * dsize[1])]
                        out_band = out_ds.GetRasterBand(k + 1)
                        out_band.WriteArray(out_data)
                        out_band.SetColorInterpretation(src_color[k])
                del out_ds
        pbar.close()

    @staticmethod
    def from_img_wf(epsg_code, img_format, wf_format, img_bands, img_path, wf_path, save_path):
        if not img_bands:
            img_bands = [0, 1, 2]

        imgs = []
        wf_dir = ''
        if os.path.isdir(img_path) and os.path.isdir(wf_path):
            imgs = glob.glob(img_path + r'\*.' + img_format)
            wf_dir = wf_path
        if os.path.isfile(img_path) and os.path.isdir(wf_path):
            if '.' + img_format in img_path and '.' + wf_format in wf_path:
                imgs.append(img_path)
                wf_dir = os.path.split(wf_path)[0]
        if not imgs:
            print('input path error.')
            exit(0)

        print('Creat GeoTiff with {0} and {1}:'.format(str.upper(img_format), str.upper(wf_format)))
        print(img_path)

        pbar = tqdm(total=len(imgs))
        for img in imgs:
            time.sleep(0.05)
            pbar.update(1)

            img_name = os.path.split(img)[-1]
            file_name = os.path.splitext(img_name)[0]
            wf_name = file_name + '.' + wf_format
            wf = os.path.join(wf_dir, wf_name)
            if not os.path.exists(wf):
                # print(wf_name, 'is not found.')
                continue

            img_data = imageio.imread(img)

            wf_paras = []
            with open(wf, 'r') as f:
                wf_para = f.readline()
                while wf_para:
                    wf_paras.append(float(wf_para))
                    wf_para = f.readline()
            geotransform = (wf_paras[4], wf_paras[0], wf_paras[1], wf_paras[5], wf_paras[2], wf_paras[3])

            driver = gdal.GetDriverByName('GTiff')
            new_raster = driver.Create(os.path.join(save_path, file_name + '.tif'), img_data.shape[1], img_data.shape[0], len(img_bands), gdal.GDT_Byte)
            new_raster.SetGeoTransform(geotransform)

            new_band = None
            for i in range(len(img_bands)):
                new_band = new_raster.GetRasterBand(i + 1)
                new_band.WriteArray(img_data[:, :, img_bands[i]])

            new_raster_srs = osr.SpatialReference()
            new_raster_srs.ImportFromEPSG(epsg_code)
            new_raster.SetProjection(new_raster_srs.ExportToWkt())
            new_band.FlushCache()
        pbar.close()

    @staticmethod
    def from_img_gtif(img_format, img_bands, img_path, gtif_path, save_path):
        if not img_bands:
            img_bands = [0, 1, 2]

        imgs = []
        gtif_dir = ''
        if os.path.isdir(img_path) and os.path.isdir(gtif_path):
            imgs = glob.glob(img_path + r'\*.' + img_format)
            gtif_dir = gtif_path
        if os.path.isfile(img_path) and '.' + img_format in img_path:
            if '.' + img_format in img_path and '.tif' in gtif_path:
                imgs.append(img_path)
                gtif_dir = os.path.split(gtif_path)[0]
        if not imgs:
            print('input path error.')
            exit(0)

        print('Creat GeoTiff with {0} and GeoTiff:'.format(str.upper(img_format)))
        print(img_path)

        pbar = tqdm(total=len(imgs))
        for img in imgs:
            time.sleep(0.05)
            pbar.update(1)

            img_name = os.path.split(img)[-1]
            file_name = os.path.splitext(img_name)[0]
            gtif_name = file_name + '.tif'
            gtif = os.path.join(gtif_dir, gtif_name)
            if not os.path.exists(gtif):
                # print(gtif_name, 'is not found.')
                continue

            img_data = imageio.imread(img)

            src_ds = gdal.Open(os.path.join(gtif_dir, gtif_name))
            if src_ds is None:
                # print('unable to open raster file:', gtif_name, '.')
                continue
            geotransform = src_ds.GetGeoTransform()
            projection = src_ds.GetProjection()

            driver = gdal.GetDriverByName('GTiff')
            new_raster = driver.Create(os.path.join(save_path, file_name + '.tif'), img_data.shape[1],
                                       img_data.shape[0], len(img_bands), gdal.GDT_Byte)
            new_raster.SetGeoTransform(geotransform)

            new_band = None
            for i in range(len(img_bands)):
                new_band = new_raster.GetRasterBand(i + 1)
                new_band.WriteArray(img_data[:, :, img_bands[i]])

            # new_raster_srs = osr.SpatialReference()
            # new_raster_srs.ImportFromEPSG(epsg_code)
            new_raster.SetProjection(projection)
            new_band.FlushCache()
        pbar.close()

    @staticmethod
    def set_nodata(nodata_val, gtif_path):
        gtifs = []
        if os.path.isdir(gtif_path):
            gtifs = glob.glob(gtif_path + r'\*.tif')
        elif os.path.isfile(gtif_path):
            if '.tif' in gtif_path or '.TIF' in gtif_path:
                gtifs.append(gtif_path)
        else:
            print('input path error.')
            exit(0)

        print('Set nodata value of Geotiff:')
        print(gtif_path)

        pbar = tqdm(total=len(gtifs))
        for gtif in gtifs:
            time.sleep(0.05)
            pbar.update(1)

            src_ds = gdal.Open(gtif, GA_Update)
            if src_ds is None:
                # print('unable to open raster file:', gtif_name)
                continue

            nband = src_ds.RasterCount
            for i in range(nband):
                src_band = src_ds.GetRasterBand(i + 1)
                # 注意黑边的数值,也可能是白边
                src_band.SetNoDataValue(nodata_val)
        pbar.close()

    @staticmethod
    def gtif_to_shp(gtif_path, save_path):
        gtifs = []
        if os.path.isdir(gtif_path):
            gtifs = glob.glob(gtif_path + r'\*.tif')
        elif os.path.isfile(gtif_path):
            if '.tif' in gtif_path or '.TIF' in gtif_path:
                gtifs.append(gtif_path)
        else:
            print('input path error.')
            exit(0)

        print('Convert Geotiff to ShapeFile:')
        print(gtif_path)

        # Stop GDAL printing both warnings and errors to STDERR
        gdal.PushErrorHandler('CPLQuietErrorHandler')
        # Make GDAL raise python exceptions for errors (warnings won't raise an exception)
        gdal.UseExceptions()

        pbar = tqdm(total=len(gtifs))
        for gtif in gtifs:
            time.sleep(0.05)
            pbar.update(1)

            gtif_name = os.path.split(gtif)[-1]
            file_name = os.path.splitext(gtif_name)[0]
            src_ds = gdal.Open(gtif)
            if src_ds is None:
                # print('unable to open gtif file:', gtif_name)
                continue

            print(src_ds.GetProjection())
            exit(0)
            srs = osr.SpatialReference(wkt=src_ds.GetProjection())
            src_band = src_ds.GetRasterBand(1)
            dst_layer_name = "POLYGONIZED_STUFF"
            driver = ogr.GetDriverByName("ESRI Shapefile")
            dst_ds = driver.CreateDataSource(os.path.join(save_path, file_name + '.shp'))
            dst_layer = dst_ds.CreateLayer(dst_layer_name, srs=srs)
            gdal.Polygonize(src_band, src_band, dst_layer, -1, [], callback=None)
        pbar.close()


if __name__ == '__main__':
    # GeoTiff.to_img('png', r'G:\GIS\Test\LC81320402017350LGN00', r'G:\GIS\Test')
    # GeoTiff.clip_by_size([1000, 1000], r'G:\GIS\Lake\Landsat8', r'G:\GIS\Lake\Landsat8\TIF')
    # GeoTiff.from_img_wf(3857, 'png', 'pgw', [], r'G:\GIS\Test', r'G:\GIS\Test', r'G:\GIS\Test')
    # GeoTiff.from_img_gtif('png', [0], r'G:\GIS\Lake\Landsat8\Segmentation\val\IMG', r'G:\GIS\Lake\Landsat8\TIF', r'G:\GIS\Lake\Landsat8\Segmentation\val\TIF')
    # GeoTiff.set_nodata(0, r'G:\GIS\Test')
    GeoTiff.gtif_to_shp(r'G:\GIS\Lake\Landsat8\Segmentation\val\TIF', r'G:\GIS\Lake\Landsat8\Segmentation\val\SHP')
    exit(0)



# -*- coding: utf-8 -*-
import os
import glob
from tqdm import tqdm
import time
from osgeo import osr
from osgeo import ogr


class ShpPolygon:
    @staticmethod
    def to_gtif():
        exit(0)

    @staticmethod
    def merge_shp(shp_path, save_path):
        if not os.path.isdir(shp_path):
            print('input path error.')
            exit(0)
        shps = glob.glob(shp_path + r'\*.shp')

        print('Merge ShapeFiles:')
        print(shp_path)

        driver = ogr.GetDriverByName("ESRI Shapefile")
        out_ds = driver.CreateDataSource(save_path)

        fst_ds = ogr.Open(shps[0])
        # print(str(fst_ds.GetLayer().GetSpatialRef()))
        # exit(0)
        srs = osr.SpatialReference(wkt=str(fst_ds.GetLayer().GetSpatialRef()))
        # srs.ImportFromEPSG(epsg_code)
        dst_layername = "MERGED_STUFF"
        out_layer = out_ds.CreateLayer(dst_layername, srs=srs)

        new_fields = ["Name"]
        new_field = ogr.FieldDefn(new_fields[0], ogr.OFTString)
        out_layer.CreateField(new_field)

        pbar = tqdm(total=len(shps))
        for shp in shps:
            time.sleep(0.05)
            pbar.update(1)

            file_name = os.path.splitext(os.path.split(shp)[-1])[0]
            src_ds = ogr.Open(shp)
            src_layer = src_ds.GetLayer()
            for src_feat in src_layer:
                out_feat = ogr.Feature(out_layer.GetLayerDefn())
                out_feat.SetField("Name", file_name)
                for i in range(1, src_feat.GetFieldCount()):
                    new_field_name = src_feat.GetFieldDefnRef(i).GetName()
                    if new_field_name not in new_fields:
                        new_fields.append(new_field_name)
                        new_field_type = src_feat.GetFieldDefnRef(i).GetType()
                        new_field = ogr.FieldDefn(new_field_name, new_field_type)
                        out_layer.CreateField(new_field)
                        out_feat.SetField(new_field_name, src_feat.GetField(i))
                out_feat.SetGeometry(src_feat.GetGeometryRef().Clone())
                out_layer.CreateFeature(out_feat)
                out_layer.SyncToDisk()
        pbar.close()

    @staticmethod
    def calc_area(shp_path):
        shps = []
        if os.path.isdir(shp_path):
            shps = glob.glob(shp_path + r'\*.shp')
        elif os.path.isfile(shp_path):
            if '.shp' in shp_path:
                shps.append(shp_path)
        else:
            print('input path error.')
            exit(0)

        print('Calculate the area of features:')
        print(shp_path)

        pbar = tqdm(total=len(shps))
        for shp in shps:
            time.sleep(0.05)
            pbar.update(1)

            driver = ogr.GetDriverByName("ESRI Shapefile")
            src_ds = driver.Open(shp, 1)

            src_layer = src_ds.GetLayer()
            new_field = ogr.FieldDefn("Area", ogr.OFTReal)
            new_field.SetPrecision(2)
            src_layer.CreateField(new_field)
            for src_feat in src_layer:
                src_geom = src_feat.GetGeometryRef()
                src_feat.SetField("Area", src_geom.GetArea())
                src_layer.SetFeature(src_feat)
        pbar.close()

    @staticmethod
    def sum_numattr(filed_name, shp_path):
        if not os.path.isfile(shp_path):
            print('input path error.')
            exit(0)

        driver = ogr.GetDriverByName("ESRI Shapefile")
        src_ds = driver.Open(shp_path, 0)
        src_layer = src_ds.GetLayer()
        sum_val = 0
        for src_feat in src_layer:
            sum_val += src_feat.GetField(filed_name)

        return sum_val

    @staticmethod
    def mean_numattr(filed_name, shp_path):
        if not os.path.isfile(shp_path):
            print('input path error.')
            exit(0)

        driver = ogr.GetDriverByName("ESRI Shapefile")
        src_ds = driver.Open(shp_path, 0)
        src_layer = src_ds.GetLayer()
        sum_val = 0
        for src_feat in src_layer:
            sum_val += src_feat.GetField(filed_name)
        mean_val = sum_val / len(src_layer)

        return mean_val

    @staticmethod
    def max_numattr(filed_name, shp_path):
        if not os.path.isfile(shp_path):
            print('input path error.')
            exit(0)

        driver = ogr.GetDriverByName("ESRI Shapefile")
        src_ds = driver.Open(shp_path, 0)
        src_layer = src_ds.GetLayer()
        max_val = None

        for src_feat in src_layer:
            val = src_feat.GetField(filed_name)
            if max_val is None or val > max_val:
                max_val = val

        return max_val

    @staticmethod
    def min_numattr(filed_name, shp_path):
        if not os.path.isfile(shp_path):
            print('input path error.')
            exit(0)

        driver = ogr.GetDriverByName("ESRI Shapefile")
        src_ds = driver.Open(shp_path, 0)
        src_layer = src_ds.GetLayer()
        min_val = None

        for src_feat in src_layer:
            val = src_feat.GetField(filed_name)
            if min_val is None or val < min_val:
                min_val = val

        return min_val

    @staticmethod
    def remove_by_numattr(fl_cond, shp_path):
        shps = []
        if os.path.isdir(shp_path):
            shps = glob.glob(shp_path + r'\*.shp')
        elif os.path.isfile(shp_path):
            if '.shp' in shp_path:
                shps.append(shp_path)
        else:
            print('input path error.')
            exit(0)

        print('Remove features by number attribute:')
        print(shp_path)

        pbar = tqdm(total=len(shps))
        for shp in shps:
            time.sleep(0.05)
            pbar.update(1)

            driver = ogr.GetDriverByName("ESRI Shapefile")
            src_ds = driver.Open(shp, 1)

            src_layer = src_ds.GetLayer()
            fl_cond_str = ''
            if_first = True
            for sel_field, conds in fl_cond.items():
                if not if_first:
                    fl_cond_str += ' and '
                else:
                    if_first = False

                for cond in conds:
                    fl_cond_str += sel_field + ' ' + cond
                    if cond != conds[-1]:
                        fl_cond_str += ' and '
            src_layer.SetAttributeFilter(fl_cond_str)

            for src_feat in src_layer:
                src_layer.DeleteFeature(src_feat.GetFID())
                src_ds.ExecuteSQL('REPACK ' + src_layer.GetName())
        pbar.close()

    @staticmethod
    def remove_by_strattr(fl_cond, shp_path):
        shps = []
        if os.path.isdir(shp_path):
            shps = glob.glob(shp_path + r'\*.shp')
        elif os.path.isfile(shp_path):
            if '.shp' in shp_path:
                shps.append(shp_path)
        else:
            print('input path error.')
            exit(0)

        print('Remove features by number attribute:')
        print(shp_path)

        pbar = tqdm(total=len(shps))
        for shp in shps:
            time.sleep(0.05)
            pbar.update(1)

            driver = ogr.GetDriverByName("ESRI Shapefile")
            src_ds = driver.Open(shp, 1)

            src_layer = src_ds.GetLayer()
            fl_cond_str = ''
            if_first = True
            for sel_field, val_fixed in fl_cond.items():
                if not if_first:
                    fl_cond_str += ' and '
                else:
                    if_first = False

                for i in range(len(val_fixed)):
                    if i != 0:
                        fl_cond_str += ' and '
                    fl_cond_str += sel_field + ' = ' + "'" + str(val_fixed[0]) + "'"

            src_layer.SetAttributeFilter(fl_cond_str)

            for src_feat in src_layer:
                src_layer.DeleteFeature(src_feat.GetFID())
                src_ds.ExecuteSQL('REPACK ' + src_layer.GetName())
        pbar.close()

    @staticmethod
    def intersection(shp1_path, shp2_path, save_path):
        if shp1_path.rsplit('.', 1)[-1] != 'shp' or shp2_path.rsplit('.', 1)[-1] != 'shp':
            print('input path error.')
            exit(0)

        print('Intersect 2 shapefile:')
        print(shp1_path)
        print(shp2_path)

        driver = ogr.GetDriverByName("ESRI Shapefile")
        src1_ds = driver.Open(shp1_path, 0)
        src2_ds = driver.Open(shp2_path, 0)
        src1_layer = src1_ds.GetLayer()
        src2_layer = src2_ds.GetLayer()

        print('unite shapefile 1:')
        pbar = tqdm(total=len(src1_layer))
        src1_union = ogr.Geometry(ogr.wkbMultiPolygon)
        for src1_feat in src1_layer:
            time.sleep(0.05)
            pbar.update(1)

            geom = src1_feat.GetGeometryRef()
            src1_union = src1_union.Union(geom)
        pbar.close()

        print('unite shapefile 2:')
        pbar = tqdm(total=len(src2_layer))
        src2_union = ogr.Geometry(ogr.wkbMultiPolygon)
        for src2_feat in src2_layer:
            time.sleep(0.05)
            pbar.update(1)

            geom = src2_feat.GetGeometryRef()
            src2_union = src2_union.Union(geom)
        pbar.close()

        print('intersection is being executed ...')
        intersection = src1_union.Intersection(src2_union)

        out_ds = driver.CreateDataSource(save_path)
        srs = osr.SpatialReference(wkt=str(src1_layer.GetSpatialRef()))
        dst_layername = "INTERSECTION_STUFF"
        out_layer = out_ds.CreateLayer(dst_layername, srs=srs)
        out_feat = ogr.Feature(out_layer.GetLayerDefn())

        print('saving new data:')
        pbar = tqdm(total=intersection.GetGeometryCount())
        for geom in intersection:
            time.sleep(0.05)
            pbar.update(1)

            if geom.GetGeometryName() != 'POLYGON':
                continue
            out_feat.SetGeometry(geom)
            out_layer.CreateFeature(out_feat)
            out_layer.SyncToDisk()
        pbar.close()

    @staticmethod
    def union(shp1_path, shp2_path, save_path):
        if shp1_path.rsplit('.', 1)[-1] != 'shp' or shp2_path.rsplit('.', 1)[-1] != 'shp':
            print('input path error.')
            exit(0)

        print('Unite 2 shapefile')
        print(shp1_path)
        print(shp2_path)

        driver = ogr.GetDriverByName("ESRI Shapefile")
        src1_ds = driver.Open(shp1_path, 0)
        src2_ds = driver.Open(shp2_path, 0)
        src1_layer = src1_ds.GetLayer()
        src2_layer = src2_ds.GetLayer()

        print('unite shapefile 1:')
        pbar = tqdm(total=len(src1_layer))
        src1_union = ogr.Geometry(3)
        for src1_feat in src1_layer:
            time.sleep(0.05)
            pbar.update(1)

            geom = src1_feat.GetGeometryRef()
            src1_union = src1_union.Union(geom)
        pbar.close()

        print('unite shapefile 2:')
        pbar = tqdm(total=len(src2_layer))
        src2_union = ogr.Geometry(3)
        for src2_feat in src2_layer:
            time.sleep(0.05)
            pbar.update(1)

            geom = src2_feat.GetGeometryRef()
            src2_union = src2_union.Union(geom)
        pbar.close()

        print('Union is being executed ...')
        union = src1_union.Union(src2_union)

        out_ds = driver.CreateDataSource(save_path)
        srs = osr.SpatialReference(wkt=str(src1_layer.GetSpatialRef()))
        dst_layername = "UNION_STUFF"
        out_layer = out_ds.CreateLayer(dst_layername, srs=srs)
        out_feat = ogr.Feature(out_layer.GetLayerDefn())

        print('saving new data:')
        pbar = tqdm(total=union.GetGeometryCount())
        for geom in union:
            time.sleep(0.05)
            pbar.update(1)

            if geom.GetGeometryName() != 'POLYGON':
                continue
            out_feat.SetGeometry(geom)
            out_layer.CreateFeature(out_feat)
            out_layer.SyncToDisk()
        pbar.close()


if __name__ == '__main__':
    # ShpPolygon.merge_shp(r'G:\GIS\Lake\Landsat8\Segmentation\val\SHP', r'G:\GIS\Lake\Landsat8\Segmentation\val\SHP\Union\merge.shp')
    # ShpPolygon.calc_area(r'G:\GIS\Nepal\GoogleBing\Segmentation\val\SHP')
    # ShpPolygon.remove_by_numattr({'Area': ['< 100']}, r'G:\GIS\Nepal\GoogleBing\Segmentation\val\SHP\union.shp')
    # ShpPolygon.remove_by_strattr({'Name': ['1', '3']}, r'G:\GIS\Test\SHP')
    ShpPolygon.union(r'G:\GIS\Lake\Landsat8\Segmentation\val\SHP\Union\merge.shp', r'G:\GIS\Lake\Landsat8\Segmentation\val\SHP\Union\merge.shp', r'G:\GIS\Lake\Landsat8\Segmentation\val\SHP\Union\merge2.shp')
    # ShpPolygon.intersection(r'G:\GIS\Test\SHP\1.shp', r'G:\GIS\Test\SHP\mask.shp', r'G:\GIS\Test\SHP\GeoProcessing\union.shp')
    # print(ShpPolygon.sum_numattr('Area', r'G:\GIS\Nepal\GoogleBing\Segmentation\val\SHP\intersection.shp'))
    # print(ShpPolygon.mean_numattr('Area', r'G:\GIS\Nepal\GoogleBing\Truth\val\SHP\val.shp'))
    # print(ShpPolygon.max_numattr('Area', r'G:\GIS\Nepal\GoogleBing\Truth\val\SHP\val.shp'))
    # print(ShpPolygon.min_numattr('Area', r'G:\GIS\Nepal\GoogleBing\Truth\val\SHP\val.shp'))
    exit(0)



from setuptools import setup

setup(
    name='AGDPK',
    version='1.0.0',
    author='Viktor Xu',
    author_email='viktorxu@qq.com',
    maintainer='Viktor Xu',
    maintainer_email='viktorxu@qq.com',
    url='',
    license='',
    description='a advanced geoscience data processing kit.',
    long_description='',
    platforms=['Windows', 'Ubuntu'],
    packages=[],
    py_modules=['raster_pro', 'vector_pro'],
    requires=[
        'GDAL',
        'imageio',
        'numpy',
        'tqdm'
    ],
    zip_safe=False
)

'''
python setup.py sdist
python setup.py install
twine upload dist/*
'''